.g-widget-readme-header{color:#555;background-color:#f0f0f0;padding:5px 6px;font-size:16px;font-weight:700}.g-widget-readme-header i{font-style:normal}.g-widget-readme-content{color:#777;border-bottom:1px solid #f0f0f0;min-height:25px;margin:5px 3px 3px;font-size:14px}
/*$vite$:1*/